@@ -20,37 +20,45 @@ conf_yaml_content = """env: qa"""
 conftest_content = """#!/usr/bin/python
 # encoding=utf-8
 
-\"\"\" Can only be modified by the administrator. Only fixtures are provided.
+\"\"\" 只能管理员编辑，只对外提供fixture。
 \"\"\"
 
 import os
+import time
 
 import pytest
 
-# Initial
+# 项目目录路径
 _project_dir = os.path.dirname(os.path.abspath(__file__))
 
 
+# 设置缓存供tep使用
 @pytest.fixture(scope="session", autouse=True)
 def _project_cache(request):
     request.config.cache.set("project_dir", _project_dir)
 
 
-# Auto import fixtures
+# 自动导入fixtures
 _fixtures_dir = os.path.join(_project_dir, "fixtures")
+_fixtures_paths = []
 for root, _, files in os.walk(_fixtures_dir):
     for file in files:
-        if os.path.isfile(os.path.join(root, file)):
-            if file.startswith("fixture_") and file.endswith(".py"):
-                _fixture_name, _ = os.path.splitext(file)
-                try:
-                    exec(f"from fixtures.{_fixture_name} import *")
-                except:
-                    pass
-                try:
-                    exec(f"from .fixtures.{_fixture_name} import *")
-                except:
-                    pass
+        if file.startswith("fixture_") and file.endswith(".py"):
+            full_path = os.path.join(root, file)
+            import_path = full_path.replace(_fixtures_dir, "").replace("\\\\", ".").replace("/", ".").replace(".py", "")
+            _fixtures_paths.append("fixtures" + import_path)
+pytest_plugins = _fixtures_paths
+
+
+# pytest hook函数
+# https://docs.pytest.org/en/latest/reference/reference.html#hooks
+def pytest_terminal_summary(terminalreporter, exitstatus, config):
+    total = terminalreporter._numcollected
+    passed = len(terminalreporter.stats.get('passed', []))
+    failed = len(terminalreporter.stats.get('failed', []))
+    error = len(terminalreporter.stats.get('error', []))
+    skipped = len(terminalreporter.stats.get('skipped', []))
+    duration = time.time() - terminalreporter._sessionstarttime
 """
 
 pytest_ini_content = """[pytest]
@@ -85,8 +93,8 @@ def env_vars(config):
     class Clazz(TepVars):
         env = config["env"]
 
-        \"\"\"Variables define start\"\"\"
-        # Environment and variables
+        \"\"\"变量定义开始\"\"\"
+        # 环境变量
         mapping = {
             \"qa\": {
                 "domain": "http://127.0.0.1:5000",
@@ -104,12 +112,12 @@ def env_vars(config):
                                              "123456",
                                              "release"),
             }
-            # Add your environment and variables
+            # 继续添加
         }
-        # Define properties for auto display
+        # 定义类属性，敲代码时会有智能提示
         domain = mapping[env]["domain"]
         mysql_engine = mapping[env]["mysql_engine"]
-        \"\"\"Variables define end\"\"\"
+        \"\"\"变量定义结束\"\"\"
 
     return Clazz()
 """
@@ -180,6 +188,30 @@ def share_your_name():
     pass
 """
 
+fixture_second_content = """#!/usr/bin/python
+# encoding=utf-8
+
+
+from tep.fixture import *
+
+
+@pytest.fixture
+def fixture_second():
+    logger.info("fixture_second")
+"""
+
+fixture_three_content = """#!/usr/bin/python
+# encoding=utf-8
+
+
+from tep.fixture import *
+
+
+@pytest.fixture
+def fixture_three():
+    logger.info("fixture_three")
+"""
+
 test_login_content = """from loguru import logger
 
 
@@ -246,85 +278,111 @@ request("post",
         )
 """
 
-flask_mock_api_content = """#!/usr/bin/python
+fastapi_mock_content = """#!/usr/bin/python
 # encoding=utf-8
 
-import json
+import uvicorn
+from fastapi import FastAPI, Request
 
-from flask import Flask, request
-
-# Flask实例
-app = Flask(__name__)
+app = FastAPI()
 
 
-def is_headers_equal(headers, data):
-    # 简单比较请求头是否一致
-    for k, v in data.items():
-        if headers.get(k) != v:
-            return False
-    return True
-
-
-def is_args_equal(args, data):
-    # 简单比较请求参数是否一致
-    for k, v in data.items():
-        if args.get(k) != v:
-            return False
-    return True
-
-
-def is_json_equal(json_, data):
-    # 简单比较请求体是否一致
-    json_ = json.loads(json_)
-    for k, v in data.items():
-        if json_.get(k) != v:
-            return False
-    return True
-
-
-@app.route("/login", methods=["POST"])
-def login():
-    if is_json_equal(request.get_data(), {"username": "dongfanger", "password": "123456"}):
+@app.post("/login")
+async def login(req: Request):
+    body = await req.json()
+    if body["username"] == "dongfanger" and body["password"] == "123456":
         return {"token": "de2e3ffu29"}
-    return "", 500
+    return ""
 
 
-@app.route("/searchSku")
-def search_sku():
-    if is_headers_equal(request.headers, {"token": "de2e3ffu29"}) and is_args_equal(request.args, {"skuName": "电子书"}):
+@app.get("/searchSku")
+def search_sku(req: Request):
+    if req.headers.get("token") == "de2e3ffu29" and req.query_params.get("skuName") == "电子书":
         return {"skuId": "222", "price": "2.3"}
-    return "", 500
+    return ""
 
 
-@app.route("/addCart", methods=["POST"])
-def add_cart():
-    if is_headers_equal(request.headers, {"token": "de2e3ffu29"}) and is_json_equal(request.get_data(),
-                                                                                    {"skuId": "222", "skuNum": "3"}):
+@app.post("/addCart")
+async def add_cart(req: Request):
+    body = await req.json()
+    if req.headers.get("token") == "de2e3ffu29" and body["skuId"] == "222":
         return {"skuId": "222", "price": "2.3", "skuNum": "3", "totalPrice": "6.9"}
-    return "", 500
+    return ""
 
 
-@app.route("/order", methods=["POST"])
-def order():
-    if is_headers_equal(request.headers, {"token": "de2e3ffu29"}) and is_json_equal(request.get_data(),
-                                                                                    {"skuId": "222", "price": "2.3",
-                                                                                     "skuNum": "3",
-                                                                                     "totalPrice": "6.9"}):
+@app.post("/order")
+async def order(req: Request):
+    body = await req.json()
+    if req.headers.get("token") == "de2e3ffu29" and body["skuId"] == "222":
         return {"orderId": "333"}
-    return "", 500
+    return ""
 
 
-@app.route("/pay", methods=["GET", "POST"])
-def pay():
-    if is_headers_equal(request.headers, {"token": "de2e3ffu29"}) and is_json_equal(request.get_data(),
-                                                                                    {"orderId": "333",
-                                                                                     "payAmount": "6.9"}):
+@app.post("/pay")
+async def pay(req: Request):
+    body = await req.json()
+    if req.headers.get("token") == "de2e3ffu29" and body["orderId"] == "333":
         return {"success": "true"}
-    return "", 500
+    return ""
 
 
-if __name__ == "__main__":
-    app.run()
+if __name__ == '__main__':
+    uvicorn.run("fastapi_mock:app", host="127.0.0.1", port=5000)
+"""
+
+http_client_content = """#!/usr/bin/python
+# encoding=utf-8
+
+import decimal
+import json
+import time
+
+import allure
+from loguru import logger
+from tep import client
+from tep.client import TepResponse
+
+
+def request_monkey_patch(req, *args, **kwargs):
+    start = time.process_time()
+    desc = ""
+    if "desc" in kwargs:
+        desc = kwargs.get("desc")
+        kwargs.pop("desc")
+    response = req(*args, **kwargs)
+    end = time.process_time()
+    elapsed = str(decimal.Decimal("%.3f" % float(end - start))) + "s"
+    log4a = "{}\\n{}status:{}\\nresponse:{}\\nelapsed:{}"
+    try:
+        kv = ""
+        for k, v in kwargs.items():
+            # if not json, str()
+            try:
+                v = json.dumps(v, ensure_ascii=False)
+            except TypeError:
+                v = str(v)
+            kv += f"{k}:{v}\\n"
+        args = list(args)
+        args += ["", ""]
+        method, url, *t = args
+        method_url = ""
+        if method:
+            method_url = f'\\nmethod:"{method}" '
+        if url:
+            method_url += f'\\nurl:"{url}" '
+        request_response = log4a.format(method_url, kv, response.status_code, response.text, elapsed)
+        logger.info(request_response)
+        allure.attach(request_response, f'{desc} request & response', allure.attachment_type.TEXT)
+    except AttributeError:
+        logger.error("request failed")
+    except TypeError:
+        logger.warning(log4a)
+    return TepResponse(response)
+
+
+def request(method, url, **kwargs):
+    client.tep_request_monkey_patch = request_monkey_patch
+    return client.request(method, url, **kwargs)
 """
 
 test_login_pay_content = """import jmespath
@@ -538,8 +596,7 @@ class Pay(BaseRequest):
         assert response.jmespath("success") == "true"
 """
 
-test_login_pay_mvc_content = """import allure
-from tep.fixture import TepVars
+test_login_pay_mvc_content = """from tep.fixture import TepVars
 
 from services.AddCart import AddCart
 from services.Login import Login
@@ -571,3 +628,132 @@ class Test:
         # 支付
         Pay(Test).post()
 """
+
+test_multi_fixture_content = """#!/usr/bin/python
+# encoding=utf-8
+
+
+def test(fixture_second, fixture_three):
+    pass
+"""
+
+test_request_monkey_patch_content = """from utils.http_client import request
+
+
+def test_login(env_vars):
+    response = request(
+        "post",
+        url=env_vars.domain + "/login",
+        desc="登录",
+        headers={"Content-Type": "application/json"},
+        json={
+            "username": "dongfanger",
+            "password": "123456",
+        }
+    )
+    assert response.status_code < 400
+"""
+
+mitm_content = """#!/usr/bin/python
+# encoding=utf-8
+
+# mitmproxy录制流量自动生成用例
+
+import os
+import time
+
+from mitmproxy import ctx
+
+project_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+tests_dir = os.path.join(project_dir, "tests")
+# tests/mitm
+mitm_dir = os.path.join(tests_dir, "mitm")
+if not os.path.exists(mitm_dir):
+    os.mkdir(mitm_dir)
+# 当前时间作为文件名
+filename = time.strftime("%Y%m%d_%H_%M_%S", time.localtime()) + ".py"
+case_file = os.path.join(mitm_dir, filename)
+# 生成用例文件
+template = \"\"\"from tep.client import request
+
+
+def test():
+\"\"\"
+if not os.path.exists(case_file):
+    with open(case_file, "w", encoding="utf8") as fw:
+        fw.write(template)
+
+
+class Record:
+    def __init__(self, domains):
+        self.domains = domains
+
+    def response(self, flow):
+        if self.match(flow.request.url):
+            # method
+            method = flow.request.method.lower()
+            ctx.log.error(method)
+            # url
+            url = flow.request.url
+            ctx.log.error(url)
+            # headers
+            headers = dict(flow.request.headers)
+            ctx.log.error(headers)
+            # body
+            body = flow.request.text or {}
+            ctx.log.error(body)
+            with open(case_file, "a", encoding="utf8") as fa:
+                fa.write(self.step(method, url, headers, body))
+
+    def match(self, url):
+        if not self.domains:
+            ctx.log.error("必须配置过滤域名")
+            exit(-1)
+        for domain in self.domains:
+            if domain in url:
+                return True
+        return False
+
+    def step(self, method, url, headers, body):
+        if method == "get":
+            body_grammar = f"params={body}"
+        else:
+            body_grammar = f"json={body}"
+        return f\"\"\"
+    # 接口描述
+    # 数据
+    # 请求
+    response = request(
+        "{method}",
+        url="{url}",
+        headers={headers},
+        {body_grammar}
+    )
+    # 数据提取
+    # var = response.jmespath("expression")
+    # 断言
+    assert response.status_code < 400
+\"\"\"
+
+
+# ==================================配置开始==================================
+addons = [
+    Record(
+        # 过滤域名
+        [
+            "http://www.httpbin.org",
+            "http://127.0.0.1:5000"
+        ],
+    )
+]
+# ==================================配置结束==================================
+
+\"\"\"
+==================================命令说明开始==================================
+# 正向代理
+mitmdump -s mitm.py
+# 反向代理
+mitmdump -s mitm.py --mode reverse:http://127.0.0.1:5000 --listen-host 127.0.0.1 --listen-port 8000
+==================================命令说明结束==================================
+\"\"\"
+"""
\ No newline at end of file
