@@ -66,6 +66,8 @@ def create_scaffold(project_name):
 
     create_folder(project_name)
     create_folder(os.path.join(project_name, "fixtures"))
+    create_folder(os.path.join(project_name, "fixtures", "second"))
+    create_folder(os.path.join(project_name, "fixtures", "second", "three"))
     create_folder(os.path.join(project_name, "tests"))
     create_folder(os.path.join(project_name, "files"))
     create_folder(os.path.join(project_name, "reports"))
@@ -81,6 +83,10 @@ def create_scaffold(project_name):
     create_file(os.path.join(project_name, "fixtures", "fixture_env_vars.py"), fixture_env_vars_content)
     create_file(os.path.join(project_name, "fixtures", "fixture_login.py"), fixture_login_content)
     create_file(os.path.join(project_name, "fixtures", "fixture_your_name.py"), fixture_your_name_content)
+    create_file(os.path.join(project_name, "fixtures", "second", "__init__.py"))
+    create_file(os.path.join(project_name, "fixtures", "second", "fixture_second.py"), fixture_second_content)
+    create_file(os.path.join(project_name, "fixtures", "second", "three", "__init__.py"))
+    create_file(os.path.join(project_name, "fixtures", "second", "three", "fixture_three.py"), fixture_three_content)
     create_file(os.path.join(project_name, "tests", "__init__.py"))
     create_file(os.path.join(project_name, "tests", "test_login.py"), test_login_content)
     create_file(os.path.join(project_name, "tests", "test_post.py"), test_post_content)
@@ -89,8 +95,12 @@ def create_scaffold(project_name):
     create_file(os.path.join(project_name, "tests", "test_login_pay.py"), test_login_pay_content)
     create_file(os.path.join(project_name, "tests", "test_login_pay_httprunner.py"), test_login_pay_httprunner_content)
     create_file(os.path.join(project_name, "tests", "test_login_pay_mvc.py"), test_login_pay_mvc_content)
+    create_file(os.path.join(project_name, "tests", "test_multi_fixture.py"), test_multi_fixture_content)
+    create_file(os.path.join(project_name, "tests", "test_request_monkey_patch.py"), test_request_monkey_patch_content)
     create_file(os.path.join(project_name, "utils", "__init__.py"))
-    create_file(os.path.join(project_name, "utils", "flask_mock_api.py"), flask_mock_api_content)
+    create_file(os.path.join(project_name, "utils", "fastapi_mock.py"), fastapi_mock_content)
+    create_file(os.path.join(project_name, "utils", "http_client.py"), http_client_content)
+    create_file(os.path.join(project_name, "utils", "mitm.py"), mitm_content)
     create_file(os.path.join(project_name, "services", "__init__.py"))
     create_file(os.path.join(project_name, "services", "Login.py"), Login_content)
     create_file(os.path.join(project_name, "services", "SearchSku.py"), SearchSku_content)
